@@ -184,7 +184,8 @@ class LoggerLoggingEvent {
                 while ($hop !== null) {
                     $className = @strtolower($hop['class']);
                     if ( !empty($className) and ($className == 'logger' or $className == 'loggercategory' or 
-                                get_parent_class($className) == 'logger') or get_parent_class($className) == 'loggercategory') {
+                                @strtolower(get_parent_class($className)) == 'logger' or
+                                @strtolower(get_parent_class($className)) == 'loggercategory')) {
                         $locationInfo['line'] = $hop['line'];
                         $locationInfo['file'] = $hop['file'];                         
                         break;
